MetadataExt

Trait MetadataExt 

1.84.0Source
pub trait MetadataExt {
Show 22 methods // Required methods fn as_raw_stat(&self) -> &stat; fn st_dev(&self) -> u64; fn st_ino(&self) -> u64; fn st_mode(&self) -> u32; fn st_nlink(&self) -> u64; fn st_uid(&self) -> u32; fn st_gid(&self) -> u32; fn st_rdev(&self) -> u64; fn st_size(&self) -> u64; fn st_atime(&self) -> i64; fn st_atime_nsec(&self) -> i64; fn st_mtime(&self) -> i64; fn st_mtime_nsec(&self) -> i64; fn st_ctime(&self) -> i64; fn st_ctime_nsec(&self) -> i64; fn st_birthtime(&self) -> i64; fn st_birthtime_nsec(&self) -> i64; fn st_blksize(&self) -> u64; fn st_blocks(&self) -> u64; fn st_flags(&self) -> u32; fn st_gen(&self) -> u32; fn st_lspare(&self) -> u32;
}
Available on Apple only.
OS-specific extensions to fs::Metadata.

Required Methods

1.1.0Source

fn as_raw_stat(&self) -> &stat

馃憥Deprecated since 1.8.0:

deprecated in favor of the accessor methods of this trait

Available on iOS or macOS only.
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).

Gain a reference to the underlying stat structure which contains the raw information returned by the OS.

The contents of the returned stat are not consistent across Unix platforms. The os::unix::fs::MetadataExt trait contains the cross-Unix abstractions contained within the raw stat.

1.8.0Source

fn st_dev(&self) -> u64

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_ino(&self) -> u64

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_mode(&self) -> u32

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_uid(&self) -> u32

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_gid(&self) -> u32

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_rdev(&self) -> u64

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_size(&self) -> u64

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_atime(&self) -> i64

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_atime_nsec(&self) -> i64

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_mtime(&self) -> i64

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_mtime_nsec(&self) -> i64

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_ctime(&self) -> i64

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_ctime_nsec(&self) -> i64

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_birthtime(&self) -> i64

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_birthtime_nsec(&self) -> i64

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_blksize(&self) -> u64

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_blocks(&self) -> u64

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_flags(&self) -> u32

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_gen(&self) -> u32

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
1.8.0Source

fn st_lspare(&self) -> u32

This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.1.0Source

impl MetadataExt for Metadata